@@ -12,11 +12,12 @@
 #include <qlayout.h>
 #include <qtooltip.h>
 #include <qwhatsthis.h>
+#include <qtimer.h>
 
 #include "knap_preferences.h"
 
 #include <iostream>
-
+using namespace std;
 /* 
  *  Constructs a KNAP_ConnectDlg which is a child of 'parent', with the 
  *  name 'name' and widget flags set to 'f' 
@@ -122,13 +123,20 @@ KNAP_ConnectDlg::KNAP_ConnectDlg( const SongList &songs,const QStringList &hotli
 }
 void KNAP_ConnectDlg::show()
 {
-   cerr << "KNAP_ConnectDlg::show()\n";
+   static bool showing = false;
+   
+   QDialog::show();
+
+//   cerr << "KNAP_ConnectDlg::show()\n";
 //   run();
-   cerr << "KNAP_ConnectDlg::show() after run()\n";
+//   cerr << "KNAP_ConnectDlg::show() after run()\n";
 //   kapp->processEvents(5000);
 //   sleep(2);
-   QDialog::show();
-   cerr << "KNAP_ConnectDlg::show() ended\n";
+   //QDialog::show(); // qt2
+//   showing = true;
+//   exec();
+//   showing = false;
+//   cerr << "KNAP_ConnectDlg::show() ended\n";
 //   sleep(2);
 }
 
@@ -192,7 +200,9 @@ up();
  if(prefs.port>=0) port = prefs.port;
 
  if(prefs.firewall==true) port = 0;
- 
+
+retry_connection: // Yes I know I shouldnt do it like this - I will redo it some time :)
+
  if(connection->open(port)==false)
  {
     cerr << "couldnt connect\n"; 
@@ -209,6 +219,10 @@ up();
  if(!connection->login(prefs.username,prefs.password,
 	  prefs.email,prefs.connectionspeed,prefs.newuser)) 
  {
+    if(connection->getLastError()==NapsterConnection::NAP_RETRY_OPENNAP)
+    {
+       goto retry_connection;
+    }
 down();
     status = STAT_NOLOGON;
 up();
