@@ -4,10 +4,11 @@
 #include <qwidget.h>
 
 #include <iostream>
+using namespace std;
 
 //#include "welcome-html.h"
 
-KNAP_HomePanel::KNAP_HomePanel(QWidget *parent,const char *name=0)
+KNAP_HomePanel::KNAP_HomePanel(QWidget *parent,const char *name)
    : QWidget(parent,name)
 {
 
