@@ -12,17 +12,65 @@
 #include <kconfig.h>
 #include <kglobal.h>
 #include <klocale.h>
+#include <qcursor.h>
 
 #include "knap_listview.h"
 
 #include "songinfo.h"
 
 #include <iostream>
+using namespace std;
 
+#include <stdio.h>
+#include <stdlib.h>
 #include <math.h>
 
 #include "mp3.xpm"
 
+class HotlistItem : public QListViewItem
+{
+public:
+  HotlistItem(QListView *parent,const char *s1,const char *s2=0,const char *s3=0,
+		   const char *s4=0,const char *s5=0,const char *s6=0,const char *s7=0)
+    : QListViewItem(parent,s1,s2,s3,s4,s5,s6,s7)
+  { }
+  virtual QString text(int col) const
+  {
+    static QString ret; // Copied on return from function so ok, even if ugly.
+    if(col==1) 
+    {
+      ret=convertSize(atol(QListViewItem::text(col)));
+      return ret;
+    }
+    else
+      return QListViewItem::text(col);
+  }
+
+  virtual QString key(int col,bool asc) const
+  {
+    static QString ret;
+    if(col==1) { // sort the size
+        ret.sprintf( "%012ld", atol(QListViewItem::text(col)) );
+        return ret;
+    }
+    else if(col==4)     // time
+    {
+       int min,sec;
+       sscanf(QListViewItem::text(col),"%d:%d",&min,&sec);
+
+       ret.sprintf( "%09ld", (min * 60) + sec);
+       return ret;
+    }
+
+    else if(col==2) { // bitrate
+        ret.sprintf( "%06ld", atol(QListViewItem::text(col)) );
+        return ret;
+    }
+    return QListViewItem::text(col);
+  }
+};
+
+
 KNAP_HotlistPanel::KNAP_HotlistPanel(QWidget *parent,const char *name)
    : QFrame(parent,name)
 {
@@ -182,7 +230,8 @@ void KNAP_HotlistPanel::popupDownload()
 void KNAP_HotlistPanel::addUser()
 {
    KNAP_AddUserDlg p(this);
-   p.show();
+   //p.show();
+   p.exec();
    // prompt for and add a user
    QString user = p.getUser();
    cerr << "add user " << user << endl; 
@@ -315,14 +364,15 @@ void KNAP_HotlistPanel::addSong(const SongInfo *song)
 
    if(user == song->user)
    { 
-      QString s_time = QString().setNum(floor(song->seconds / 60));
+      QString s_time = QString().setNum((long)floor((double)song->seconds / 60));
       cerr << "KNAP_HotlistPanel::addSong(): time is " << song->seconds << endl;
       s_time += ":";
       int sec = song->seconds % 60;
       if (sec < 10) s_time += "0";
       s_time += QString().setNum(sec);  
 
-      i = new QListViewItem(songview,song->filename,convertSize(song->size),
+      i = new HotlistItem(songview,song->filename,QString().setNum(song->size),
+	    //convertSize(song->size),
 	    QString().setNum(song->bitrate),QString().setNum(song->freq),s_time);
       // set the pixmap just to add a bit of 'color'
       if(i) i->setPixmap(0,QPixmap((const char **)mp3_xpm));
