@@ -31,10 +31,13 @@ email                : donoghue@chariot.net.au
 #include <kconfig.h>
 #include <kglobal.h>
 
+#include <qcursor.h>
+
 #include "songinfo.h"
 #include "support_funcs.h"
 
-#include <iostream.h>
+#include <iostream>
+using namespace std;
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
@@ -419,7 +422,7 @@ void KNAP_SearchPanel::addSearchItem(SongInfo *song)
    char buf[10];
    sprintf(buf,"%05d",song->speed);
 
-   QString s_time = QString().setNum(floor(song->seconds / 60));
+   QString s_time = QString().setNum(floor((double)song->seconds / 60.0));
    s_time += ":";
    int sec = song->seconds % 60;
    if (sec < 10) s_time += "0";
