@@ -32,6 +32,7 @@ email                : donoghue@chariot.net.au
 //#include "napstertransfer.h"
 #include "napsterdownload1.h"
 #include "napsterupload.h"
+#include "napsterconnection.h"
 
 #include "knap_preferences.h"
 
@@ -43,7 +44,12 @@ email                : donoghue@chariot.net.au
 
 #include <qtimer.h>
 
-#include <iostream.h>
+#include <iostream>
+
+#include <qpainter.h>
+#include <qcursor.h>
+
+using namespace std;
 
 #define UPDATETIME 2
 
@@ -80,8 +86,8 @@ class DownloadListItem : public QListViewItem
 	       ret=""; // i18n("Unknown");
 	       return ret;
 	    }
-	    int hours = (int)floor(timeleft / 3600);
-	    int minutes = (int)floor((timeleft % 3600) / 60);
+	    int hours = (int)floor((double)(timeleft / 3600));
+	    int minutes = (int)floor((double)((timeleft % 3600) / 60));
 	    int seconds = timeleft % 60;
 	    ret = QString().setNum(hours).rightJustify(2, '0') + ":" +
 	       QString().setNum(minutes).rightJustify(2, '0') + ":" +
@@ -350,7 +356,7 @@ void KNAP_TransferPanel::popupDownloadTerminate()
       cerr << "KNAP_TransferPanel::popupDownloadTerminate(): " << song.filename << endl;
 
       // now find in dload list by the id - not an error - a terminate
-      stopDownload(&song,true,false);
+      stopDownload(&song,true, 0);
 
    }
 }
@@ -472,7 +478,7 @@ void KNAP_TransferPanel::addDownloadItem(const char *user,const char *file)
    transfers.append(song);
 }
 
-bool KNAP_TransferPanel::stopDownload(SongInfo *si,bool findbyid,bool naperror)
+bool KNAP_TransferPanel::stopDownload(SongInfo *si,bool findbyid,int naperror)
 {
    SongInfo *song;
    song=transfers.first();
@@ -491,7 +497,12 @@ bool KNAP_TransferPanel::stopDownload(SongInfo *si,bool findbyid,bool naperror)
 	 if(!naperror)
 	    song->status = NapsterTransfer::DL_KILLED;
 	 else 
-	    song->status = NapsterTransfer::DL_REMOTEERROR;
+	 {
+	    if(naperror == NAP_REMOTEQUEUEFULL)
+	    	song->status = NapsterTransfer::DL_REMOTEQUEUEFULL;
+	    else
+	    	song->status = NapsterTransfer::DL_REMOTEERROR;
+	 }
 
 	 return true;
       }
@@ -635,8 +646,9 @@ void KNAP_TransferPanel::updateTransferItem(SongInfo *sg,bool isdownload)
 	 it->setText(DLV_READ,rs);
 	 it->setText(DLV_RATE,QString().setNum(sg->bps));
 
-	 if(sg->status!=NapsterTransfer::DL_REMOTEERROR 
-	       || (sg->dload==0 && sg->status==NapsterTransfer::DL_REMOTEERROR))
+	 if(sg->status!=NapsterTransfer::DL_REMOTEERROR || sg->status!=NapsterTransfer::DL_REMOTEQUEUEFULL
+	       || (sg->dload==0 && sg->status==NapsterTransfer::DL_REMOTEERROR)
+	       || (sg->dload==0 && sg->status==NapsterTransfer::DL_REMOTEQUEUEFULL))
 	 {
 	    it->setText(DLV_STATUS,convertDownloadStatus(sg->status)); // status
 	 }
@@ -748,6 +760,10 @@ QString KNAP_TransferPanel::convertDownloadStatus(long s)
       case NapsterTransfer::DL_REMOTEERROR:
 	 str=i18n("Remote error");
 
+	 break; 
+      case NapsterTransfer::DL_REMOTEQUEUEFULL:
+	 str=i18n("Remote queue full");
+
 	 break; 
       default:
 	 str="??????";
