@@ -101,7 +101,7 @@ public:
   bool startUpload(KSocket *s,SongInfo *sg, const char *saveto,const char *us);
   bool startUpload(SongInfo *sg,const char *us);
 
-  bool stopDownload(SongInfo *sg,bool findbyid=false,bool naperror=false);
+  bool stopDownload(SongInfo *sg,bool findbyid=false,int naperror=0);
 
   bool showDownloadPath() const;
   void setShowDownloadPath(bool yes);
