@@ -1,4 +1,6 @@
 #include <iostream>
+using namespace std;
+
 #include <stdio.h> // for sscanf
 
 #include <klocale.h>
@@ -68,6 +70,10 @@
 
 #include "napsterdownload1.h"
 
+// added for kde3
+#include "kstatusbar.h"
+//-
+
 #define UPDATETIME 2
 
 /* 
@@ -236,7 +242,8 @@ void Knapster2::setupTabs()
 void Knapster2::menuConnectTo()
 {
    KNAP_IPAddressDlg addr(this,"Connect-to");
-   addr.show();
+   addr.exec();
+   //addr.show();
    
    QString server = addr.getIPAddress();
    
@@ -256,7 +263,8 @@ void Knapster2::menuConnect()
    QStringList hotlist = ((KNAP_HotlistPanel *)tab_4)->getUsers(); 
 
    KNAP_ConnectDlg p(slist,hotlist,this,"Connect");
-   p.show();
+   //kde3 p.show();
+   p.exec();
 
    connection = p.getConnection();
 
@@ -279,7 +287,8 @@ void Knapster2::menuRecent(const KURL &url)
    QStringList hotlist = ((KNAP_HotlistPanel *)tab_4)->getUsers(); 
 
    KNAP_ConnectDlg p(slist,hotlist,this,"Connect",host);
-   p.show();
+   //kde3 p.show();
+   p.exec();
 
    connection = p.getConnection();
 
@@ -289,7 +298,8 @@ void Knapster2::menuNapigator()
 {
    // get server from napigator and connect
    KNAP_NapigatorDlg p(this,"Napigator",true);
-   p.show();
+   //kde3 p.show();
+   p.exec();
    QString server = p.getSelectedServer();
 
    cerr << "Knapster2::menuNapigator(): " << server << endl;
@@ -338,7 +348,8 @@ void Knapster2::postConnect()
 void Knapster2::menuPreferences()
 {
    KNAP_PreferencesDlg p(this,"prefs",true);
-   p.show();
+   //kde3 p.show();
+   p.exec();
 }
 void Knapster2::menuChannels()
 {
@@ -358,6 +369,7 @@ void Knapster2::menuChannels()
    }
    if(channellist)
    {
+      //channellist->show();
       channellist->show();
 
       channellist->clear();
@@ -373,7 +385,8 @@ void Knapster2::menuCreateChannel()
    if(!connection) return;
    
    KNAP_CreateChannelDlg p(this,"chanlist");
-   p.show();
+   //p.show();
+   p.exec();
    // getname if there was one
    QString n = p.getChannelName();
    if(n.length()>0)
@@ -564,7 +577,13 @@ void Knapster2::napsterMessage(NAPBLOCKPTR msg)
 	 ((KNAP_ChatManagerPanel *)tab_1)->writeUserMessage(msg->data);
 	 break;
 
+      case NAP_REMOTEQUEUEFULL: //TODO **********
 
+	 tmpinfo = parseRemoteQueueBuffer(msg->data);
+	 if(tmpinfo)
+	    downloadpanel->stopDownload(tmpinfo, false,  msg->type);
+	 
+	 break;
       case NAP_DOWNLOAD_ERROR:
       case NAP_GET_ERROR:	 
 	 msgstr = QString("** GET error: ") + msg->data;
@@ -572,7 +591,7 @@ void Knapster2::napsterMessage(NAPBLOCKPTR msg)
 	 
 	 tmpinfo=parseDownloadErrorBuffer(msg->data);
 	 // find by name - report as an error
-         if(tmpinfo) downloadpanel->stopDownload(tmpinfo,false,true);
+         if(tmpinfo) downloadpanel->stopDownload(tmpinfo,false, msg->type);
 
 	 break; 
       case NAP_DOWNLOAD_RESULT:
@@ -672,11 +691,13 @@ void Knapster2::chatCommand(const char *comm)
    if(command == "/chan")
    {
       QString chan = extractString(tmp);
+      tmp = tmp.stripWhiteSpace();
       connection->sendChannelMessage(chan,tmp);
    }
    else if(command == "/msg")
    {
       QString user = extractString(tmp);
+      tmp = tmp.stripWhiteSpace();
       connection->sendUserMessage(user,tmp);
    }
    else if(command == "/talk")
@@ -924,7 +945,21 @@ SongInfo * Knapster2::parseDownloadErrorBuffer(char *buff)
 
    return &si;
 }
-   
+/*
+SongInfo * Knapster2::parseRemoteQueueBuffer(char *buff)
+{
+   static SongInfo si;
+
+   QString tmp;
+   QString work=buff;
+
+   si.user=extractString(work);
+
+   si.filename=extractString(work);
+
+   return &si;
+} 
+*/
 // parse a browse block data for the song info and create a temp
 // SOngInfo from it
 // // returns NULL on an invalid one  
@@ -966,7 +1001,7 @@ SongInfo * Knapster2::parseRemoteQueueBuffer(char *buff)
    si.filename=extractString(work);
 
    tmp=extractString(work);
-   if(!tmp.isNull()) si.speed=QString(tmp).toInt();
+   if(!tmp.isNull()) si.songnum=QString(tmp).toInt(); // NOTE: using songnum to hold num of downloads
 
    if(tmp.isNull()) return NULL; //warped data???
 
