@@ -41,7 +41,8 @@ email                : donoghue@chariot.net.au
 
 #include <kapp.h>
 
-#include <iostream.h>
+#include <iostream>
+using namespace std;
 
 #include "songinfo.h"
 // for doing looping inbetween parts set this 0- not that it makes much difference
@@ -52,6 +53,27 @@ email                : donoghue@chariot.net.au
 #define INADDR_NONE -1
 #endif
 
+/*
+// for little endian machines such as i386
+static unsigned short convertToBigShort(unsigned short x)
+{
+  return ( ((x&0xFF)<<8) | (x>>8) ) ;
+}
+static unsigned long convertToBigLong(unsigned long x)
+{
+  return ( ((x&0xFF)<<24) | ((x&0xFF00)<<8) | ((x&0xFF0000)>>8) | (x>>24) );
+}
+
+static unsigned short convertToLittleShort(unsigned short x)
+{
+  return x;
+}
+static unsigned long convertToLittleLong(unsigned long v)
+{
+  return x;
+}
+*/
+
 // error strings - match those from NapError 
 const char *NapsterConnection::errorstr[]=
 {
@@ -66,6 +88,7 @@ const char *NapsterConnection::errorstr[]=
    "Could not create a new user - perhaps this name is already in use",
    "Invalid username/password for new user - use a different name/password.",
    "Extended knapster Error",
+   "Failed connect as napster client - retrying as opennap.",
    "Unknown error",
    ""
 };
@@ -85,6 +108,8 @@ const char *NapsterConnection::getLastErrorStr() const
    NapsterConnection::NapsterConnection(QObject *parent, const char *name)
 : QObject(parent,name)
 {
+   _use_bigendian = true; // start of trying to use this
+
    incominglist.setAutoDelete(true);
 
    _block_pos = 0;
@@ -154,10 +179,10 @@ bool NapsterConnection::open(int port)
 //   kapp->processEvents(1000);
 #endif
 
-   if(std::connect(_napstersock,(sockaddr
+   if(::connect(_napstersock,(sockaddr
 	       *)&_sockaddr,sizeof(struct sockaddr))<0) 
    {
-      std::close(_napstersock);
+      ::close(_napstersock);
       _napstersock=-1;
       cerr<<"NapsterConnection::open(): Can't connect!\n"<<flush;
       _lasterror=NAP_NO_CONNECT;
@@ -374,7 +399,7 @@ void NapsterConnection::timeout()
        }
        // kill from list
        else 
-	  std::close(i->getSocket());
+	  ::close(i->getSocket());
        
        incominglist.removeRef(i);
      }
@@ -472,7 +497,8 @@ bool NapsterConnection::login(const char *_username,const char *password,
 
       tmp=username + QString(" ") + password + QString(" ") 
 	 + QString().setNum(_listenerport)
-	 + " \"knapster2-" VERSION "\" " + QString().setNum(conn) + QString(" ") 
+	 + " \"knapster2." VERSION "\" " 
+	 + QString().setNum(conn) + QString(" ") 
 	 + email;
 
       //    len=tmp.length();
@@ -524,7 +550,9 @@ bool NapsterConnection::login(const char *_username,const char *password,
 
       tmp=QString(username) + QString(" ") + password + QString(" ") 
 	 + QString().setNum(_listenerport) 
-	 + " \"knapster2-" VERSION "\" " + QString().setNum(conn);
+	 + " \"v2.0 BETA 10.3\" "
+	 //+ " \"knapster2-" VERSION "\" " 
+	 + QString().setNum(conn) + " 5201 0";
 
 #ifdef DEBUG_1
       // only print out this kind of info in special debug mode
@@ -546,6 +574,42 @@ bool NapsterConnection::login(const char *_username,const char *password,
 
       cout << "Last Error: " << getLastErrorStr() << endl;
 
+      // we got an error here!! - maybe we are connecting to an opennap server
+      // that has the old style bytes - lets try again
+      if(ptr->type==NAP_ERROR && ptr->size==0 && _use_bigendian ==true) 
+      {
+	 cout<<"login error: "<<ptr->data<<endl<<flush;
+         cout << "retrying as opennap\n";
+
+	 _use_bigendian = false;
+
+	 _lasterror = NAP_RETRY_OPENNAP;
+
+	 return false;
+
+      }
+/*	 
+         tmp=QString(username) + QString(" ") + password + QString(" ") 
+	   + QString().setNum(_listenerport) 
+	   + " \"v2.0 BETA 10.3\" "
+	   //+ " \"knapster2-" VERSION "\" " 
+	   + QString().setNum(conn) + "5201 0";
+
+#ifdef DEBUG_1
+         // only print out this kind of info in special debug mode
+         cerr << "NapsterConnection::login() retry: " << tmp << endl;
+#endif
+         writeBlock(NAP_LOGIN_REQ,tmp);
+
+         ptr=readBlock();
+
+         cout<<"resp: ["<<ptr->type<<"] "<<" ["<<ptr->size<<"] "
+	   <<ptr->data<<endl<<flush;
+
+         cout << "Last Error: " << getLastErrorStr() << endl;
+      }
+*/
+      
       if(ptr->type==NAP_ERROR) 
       {
 	 cout<<"login error: "<<ptr->data<<endl<<flush;
@@ -655,9 +719,16 @@ NAPBLOCKPTR NapsterConnection::readBlock(bool waitfordata)
          cout<<"read err1: "<<s<<endl<<flush;
         return &error_block;
       }
-
-      ptr->size=NAP_TO_SHORT(ptr->size); // make sure its in the right endian
-      ptr->type=NAP_TO_SHORT(ptr->type);
+      if(_use_bigendian==true)
+      {
+        ptr->size=BIG_NAP_TO_SHORT(ptr->size); // make sure its in the right endian
+        ptr->type=BIG_NAP_TO_SHORT(ptr->type);
+      }
+      else
+      {
+        ptr->size=SMALL_NAP_TO_SHORT(ptr->size); // make sure its in the right endian
+        ptr->type=SMALL_NAP_TO_SHORT(ptr->type);
+      }
 
       if((signed short int)ptr->size < 0 || ptr->size > MAX_NAP_BLOCK) 
       {
@@ -688,8 +759,16 @@ NAPBLOCKPTR NapsterConnection::readBlock(bool waitfordata)
        _block_pos = readComm(_buffer,MIN_NAP_BLOCK);
        if(_block_pos == MIN_NAP_BLOCK) 
        {
-	  ptr->size=NAP_TO_SHORT(ptr->size); 
-          ptr->type=NAP_TO_SHORT(ptr->type);
+	  if(_use_bigendian==true)
+	  {
+	    ptr->size=BIG_NAP_TO_SHORT(ptr->size); 
+            ptr->type=BIG_NAP_TO_SHORT(ptr->type);
+	  }
+	  else
+	  {
+	    ptr->size=SMALL_NAP_TO_SHORT(ptr->size); 
+            ptr->type=SMALL_NAP_TO_SHORT(ptr->type);
+	  }
        }
        // make sure its in the right endian
        if(_block_pos<0)
@@ -714,8 +793,16 @@ NAPBLOCKPTR NapsterConnection::readBlock(bool waitfordata)
        
        if(_block_pos == MIN_NAP_BLOCK) 
        {
-	  ptr->size=NAP_TO_SHORT(ptr->size); 
-          ptr->type=NAP_TO_SHORT(ptr->type);
+	  if(_use_bigendian==true)
+	  {
+	    ptr->size=BIG_NAP_TO_SHORT(ptr->size); 
+            ptr->type=BIG_NAP_TO_SHORT(ptr->type);
+	  }
+	  else
+	  {
+	    ptr->size=SMALL_NAP_TO_SHORT(ptr->size); 
+            ptr->type=SMALL_NAP_TO_SHORT(ptr->type);
+	  }
        }
        // make sure its in the right endian
      }
@@ -781,8 +868,16 @@ int NapsterConnection::writeBlock(int type,const QString &data)
    int s;
 
    // fix for the endianess problem
-   blk.size=SHORT_TO_NAP(data.length());
-   blk.type=SHORT_TO_NAP(type);
+   if(_use_bigendian==true)
+   {
+     blk.size=BIG_SHORT_TO_NAP(data.length());
+     blk.type=BIG_SHORT_TO_NAP(type);
+   }
+   else
+   {
+     blk.size=SMALL_SHORT_TO_NAP(data.length());
+     blk.type=SMALL_SHORT_TO_NAP(type);
+   }
 
    s=writeComm((char *)&blk,4);
    if(s!=-1) 
@@ -824,7 +919,7 @@ bool NapsterConnection::setupListener(int _port)
 #ifdef DEBUG_1
 	 cerr<< "bind error in connection listener\n"<<flush;
 #endif
-	 std::close(local);
+	 ::close(local);
 	 local=-1;
 	 _lasterror=NAP_NO_BIND;
 	 return false;
