@@ -22,7 +22,7 @@
   *@author jade
   */
 
-#include <iostream.h>
+#include <iostream>
 //#include <string>
 
 #include <ksock.h>  // FIXME
@@ -37,25 +37,29 @@
 // check for endianism
 #if __BYTE_ORDER == __LITTLE_ENDIAN
 // i386 type
- #define NAP_TO_SHORT(x) (x)
- #define NAP_TO_LONG(x)  (x)
- #define SHORT_TO_NAP(x) (x)
- #define LONG_TO_NAP(x)  (x)
+ #define FIX_S(x) ( ((x&0xFF)<<8) | (x>>8) )
+
+ #define BIG_NAP_TO_SHORT(x) FIX_S(x)
+ #define BIG_SHORT_TO_NAP(x) FIX_S(x)
+
+ #define SMALL_NAP_TO_SHORT(x) (x)
+ #define SMALL_SHORT_TO_NAP(x) (x)
+
 #else
  // PPC  etc
  #define FIX_S(x) ( ((x&0xFF)<<8) | (x>>8) )
- #define FIX_L(x) ( ((x&0xFF)<<24) | ((x&0xFF00)<<8) | ((x&0xFF0000)>>8) | (x>>24) )
 
- #define NAP_TO_SHORT(x) FIX_S(x)
- #define NAP_TO_LONG(x)  FIX_L(x)
- #define SHORT_TO_NAP(x) FIX_S(x)
- #define LONG_TO_NAP(x)  FIX_L(x)
+ #define SMALL_NAP_TO_SHORT(x) FIX_S(x)
+ #define SMALL_SHORT_TO_NAP(x) FIX_S(x)
+
+ #define BIG_NAP_TO_SHORT(x) (x)
+ #define BIG_SHORT_TO_NAP(x) (x)
 
 #endif
 
 // default server for besthost
 #define SERVER_ADDR "server.napster.com" 
-#define SERVER_PORT 8875
+#define SERVER_PORT 8876
 
 // server msg numbers
 #define NAP_ERROR          0
@@ -279,6 +283,7 @@ public:
          NAP_NO_DOWNLOAD, NAP_NO_SOCKET,NAP_NO_BIND,
          NAP_NO_CREATEUSER,NAP_BAD_USERNAME,
 	 NAP_EXTENDED_ERROR,
+	 NAP_RETRY_OPENNAP,
          NAP_LAST
   } NapError;
 
@@ -384,6 +389,8 @@ private: // data
 
   int _block_pos;
 
+  bool _use_bigendian;
+
   bool _connected;
   bool _havehost;
 
