@@ -19,7 +19,8 @@
 
 #include "md5.h"
 
-#include <iostream.h>
+#include <iostream>
+using namespace std;
 
 #include <qdir.h>
 #include <qfile.h>
